==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QEnterEvent_shell.h <==
#ifndef QENTEREVENT_SHELL_H
#define QENTEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QEnterEvent_shell : public QEnterEvent, public QtJambiShellInterface
{
public:
    QEnterEvent_shell(const QEnterEvent& arg__1);
    QEnterEvent_shell(const QPointF& localPos0, const QPointF& scenePos1, const QPointF& globalPos2, const QPointingDevice* device3 = QPointingDevice::primaryPointingDevice());
    ~QEnterEvent_shell() override;

    QEnterEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QEnterEvent_access : public QEnterEvent
{
    void __qt_assign_cref_QEnterEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QENTEREVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QEnterEvent_shell.h <==
#ifndef QENTEREVENT_SHELL_H
#define QENTEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QEnterEvent_shell : public QEnterEvent, public QtJambiShellInterface
{
public:
    QEnterEvent_shell(const QEnterEvent& arg__1);
    QEnterEvent_shell(const QPointF& localPos0, const QPointF& scenePos1, const QPointF& globalPos2, const QPointingDevice* device3 = QPointingDevice::primaryPointingDevice());
    ~QEnterEvent_shell() override;

    QEnterEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QEnterEvent_access : public QEnterEvent
{
    void __qt_assign_cref_QEnterEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QENTEREVENT_SHELL_H
